summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAnthony Sottile <asottile@umich.edu>2021-09-08 18:51:41 -0400
committerGitHub <noreply@github.com>2021-09-08 18:51:41 -0400
commit03401a66cbdb4a2c51aaf6aec825b82c00fc62cb (patch)
tree6726d08914386b25aff6610450e963c6efc083d7
parenteea10665da3d32e86bbcdc229890269d5ed624dc (diff)
parenta46b61901e796fcfa6761bad405558077eca7a4a (diff)
downloadflake8-03401a66cbdb4a2c51aaf6aec825b82c00fc62cb.tar.gz
Merge pull request #1383 from PyCQA/rename_test
fix test name after refactor
-rw-r--r--tests/unit/test_base_formatter.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/unit/test_base_formatter.py b/tests/unit/test_base_formatter.py
index 9fe2c4e..8958903 100644
--- a/tests/unit/test_base_formatter.py
+++ b/tests/unit/test_base_formatter.py
@@ -125,8 +125,8 @@ def test_write_uses_an_output_file(tee, capsys):
]
-def test_write_uses_print(capsys):
- """Verify that we use the print function without an output file."""
+def test_write_produces_stdout(capsys):
+ """Verify that we write to stdout without an output file."""
line = "Something to write"
source = "source"